@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-04-16 14:38:22
-@LastEditTime: 2020-11-06 11:12:03
-@LastEditors: ChenXiaolei
-@Description: 
+:Author: ChenXiaolei
+:Date: 2020-04-16 14:38:22
+:LastEditTime: 2020-11-06 11:12:03
+:LastEditors: ChenXiaolei
+:Description: 
 """
 
 from . import config
