@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-03-06 23:17:54
-@LastEditTime: 2020-11-23 17:34:10
-@LastEditors: ChenXiaolei
-@Description: 数据库基础操作类
+:Author: ChenXiaolei
+:Date: 2020-03-06 23:17:54
+:LastEditTime: 2020-12-23 17:07:18
+:LastEditors: ChenXiaolei
+:Description: 数据库基础操作类
 """
 
 from seven_framework.mysql import MySQLHelper
@@ -16,10 +16,10 @@ from seven_framework import *
 class BaseModel:
     def __init__(self, model_class, sub_table):
         """
-        @description: 基础数据库操作类
-        @param model_class: 实体对象类
-        @param sub_table: 分表标识
-        @last_editors: ChenXiaolei
+        :Description: 基础数据库操作类
+        :param model_class: 实体对象类
+        :param sub_table: 分表标识
+        :last_editors: ChenXiaolei
         """
         # 实体对象类
         self.model_class = model_class
@@ -33,10 +33,10 @@ class BaseModel:
 
     def __convert_field_type(self, field_value):
         """
-        @description: 数据库字段类型兼容转换
-        @param field_value: 字段值
-        @return: 转换类型后的字段值
-        @last_editors: ChenXiaolei
+        :Description: 数据库字段类型兼容转换
+        :param field_value: 字段值
+        :return: 转换类型后的字段值
+        :last_editors: ChenXiaolei
         """
         if isinstance(field_value, datetime.datetime):
             return field_value.strftime('%Y-%m-%d %H:%M:%S')
@@ -50,10 +50,10 @@ class BaseModel:
 
     def __row_entity(self, data):
         """
-        @description: 单条数据转成对象
-        @param data :数据字典
-        @return: 模型实体
-        @last_editors: ChenXiaolei
+        :Description: 单条数据转成对象
+        :param data :数据字典
+        :return: 模型实体
+        :last_editors: ChenXiaolei
         """
         field_list = self.model_obj.get_field_list()
         if data is None or len(field_list) == 0:
@@ -66,10 +66,10 @@ class BaseModel:
 
     def __row_entity_list(self, data_list):
         """
-        @description: 数据列表返回对象
-        @param data_list: 数据字典数组
-        @return: 模型实体列表
-        @last_editors: ChenXiaolei
+        :Description: 数据列表返回对象
+        :param data_list: 数据字典数组
+        :return: 模型实体列表
+        :last_editors: ChenXiaolei
         """
         field_list = self.model_obj.get_field_list()
         if data_list is None or len(field_list) == 0:
@@ -88,14 +88,14 @@ class BaseModel:
 
     def get_list(self, where='', group_by='', order_by='', limit='', params=None):
         """
-        @description: 根据条件获取列表
-        @param where: 数据库查询条件语句
-        @param group_by: GROUP BY 语句
-        @param order_by:  ORDER BY 语句
-        @param limit:  LIMIT 语句
-        @param params: 参数化查询参数
-        @return: 模型实体列表
-        @last_editors: ChenXiaolei
+        :Description: 根据条件获取列表
+        :param where: 数据库查询条件语句
+        :param group_by: GROUP BY 语句
+        :param order_by:  ORDER BY 语句
+        :param limit:  LIMIT 语句
+        :param params: 参数化查询参数
+        :return: 模型实体列表
+        :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
             where = " WHERE " + where
@@ -118,16 +118,16 @@ class BaseModel:
                       order_by='',
                       params=None):
         """
-        @description: 分页获取数据
-        @param field: 查询字段 
-        @param page_index: 分页页码 0为第一页
-        @param page_size: 分页返回数据数量
-        @param where: 数据库查询条件语句
-        @param group_by: GROUP BY 语句
-        @param order_by:  ORDER BY 语句
-        @param params: 参数化查询参数
-        @return: 模型实体列表
-        @last_editors: ChenXiaolei
+        :Description: 分页获取数据
+        :param field: 查询字段 
+        :param page_index: 分页页码 0为第一页
+        :param page_size: 分页返回数据数量
+        :param where: 数据库查询条件语句
+        :param group_by: GROUP BY 语句
+        :param order_by:  ORDER BY 语句
+        :param params: 参数化查询参数
+        :return: 模型实体列表
+        :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
             where = " WHERE " + where
@@ -151,13 +151,13 @@ class BaseModel:
 
     def get_entity(self, where='', group_by='', order_by='',  params=None):
         """
-        @description: 根据条件获取实体对象
-        @param where: 数据库查询条件语句
-        @param group_by: GROUP BY 语句
-        @param order_by:  ORDER BY 语句
-        @param params: 参数化查询参数
-        @return: 模型实体
-        @last_editors: ChenXiaolei
+        :Description: 根据条件获取实体对象
+        :param where: 数据库查询条件语句
+        :param group_by: GROUP BY 语句
+        :param order_by:  ORDER BY 语句
+        :param params: 参数化查询参数
+        :return: 模型实体
+        :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
             where = " WHERE " + where
@@ -171,10 +171,10 @@ class BaseModel:
 
     def get_entity_by_id(self, primary_key_id):
         """
-        @description: 根据主键值获取实体对象
-        @param primary_key_id: 主键ID值 
-        @return: 模型实体
-        @last_editors: ChenXiaolei
+        :Description: 根据主键值获取实体对象
+        :param primary_key_id: 主键ID值 
+        :return: 模型实体
+        :last_editors: ChenXiaolei
         """
         sql = f"SELECT * FROM {self.table_name} WHERE {self.primary_key_field}=%s;"
         list_row = self.db.fetch_one_row(sql, [primary_key_id])
@@ -182,13 +182,13 @@ class BaseModel:
 
     def get_total(self, where='', group_by='', field=None, params=None):
         """
-        @description: 根据条件获取数据数量
-        @param where: 数据库查询条件语句
-        @param group_by: GROUP BY 语句
-        @param params: 参数化查询参数
-        @param field: count(传参)
-        @return: 查询符合条件的行的数量
-        @last_editors: ChenXiaolei
+        :Description: 根据条件获取数据数量
+        :param where: 数据库查询条件语句
+        :param group_by: GROUP BY 语句
+        :param params: 参数化查询参数
+        :param field: count(传参)
+        :return: 查询符合条件的行的数量
+        :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
             where = " WHERE " + where
@@ -198,15 +198,18 @@ class BaseModel:
             field = self.primary_key_field
         sql = f"SELECT COUNT({field}) AS count FROM {self.table_name}{where}{group_by};"
         list_row = self.db.fetch_one_row(sql, params)
-        return list_row['count']
+        
+        if list_row and 'count' in list_row:
+            return list_row['count']
+        return 0
 
     def del_entity(self, where, params=None):
         """
-        @description: 根据条件删除数据库中的数据
-        @param where: 数据库查询条件语句
-        @param params: 参数化查询参数
-        @return: 
-        @last_editors: ChenXiaolei
+        :Description: 根据条件删除数据库中的数据
+        :param where: 数据库查询条件语句
+        :param params: 参数化查询参数
+        :return: 
+        :last_editors: ChenXiaolei
         """
         if where:
             where = " WHERE " + where
@@ -227,10 +230,10 @@ class BaseModel:
 
     def add_entity(self, model, ignore=False):
         """
-        @description: 数据入库
-        @param model: 模型实体 
-        @return: 如果主键为自增ID，返回主键值
-        @last_editors: ChenXiaolei
+        :Description: 数据入库
+        :param model: 模型实体 
+        :return: 如果主键为自增ID，返回主键值
+        :last_editors: ChenXiaolei
         """
         field_list = self.model_obj.get_field_list()
         if len(field_list) == 0:
@@ -260,12 +263,12 @@ class BaseModel:
 
     def add_list(self, model_list, ignore=False, transaction=False):
         """
-        @description: 实体列表入库
-        @param model_list: 实体列表
-        @param ignore: 忽略已存在的记录
-        @param transaction: 是否事务提交
-        @return: 执行成功True 执行失败False
-        @last_editors: ChenXiaolei
+        :Description: 实体列表入库
+        :param model_list: 实体列表
+        :param ignore: 忽略已存在的记录
+        :param transaction: 是否事务提交
+        :return: 执行成功True 执行失败False
+        :last_editors: ChenXiaolei
         """
         if not model_list or len(model_list) == 0:
             return False
@@ -304,12 +307,12 @@ class BaseModel:
 
     def add_update_entity(self, model, update_sql, params=None):
         """
-        @description: 数据入库,遇到主键冲突则更新指定字段
-        @param model: 模型实体 
-        @param update_sql: 如果主键冲突则执行的更新sql语句
-        @param params: 参数化查询参数
-        @return: 如果主键为自增ID，返回主键值
-        @last_editors: ChenXiaolei
+        :Description: 数据入库,遇到主键冲突则更新指定字段
+        :param model: 模型实体 
+        :param update_sql: 如果主键冲突则执行的更新sql语句
+        :param params: 参数化查询参数
+        :return: 如果主键为自增ID，返回主键值
+        :last_editors: ChenXiaolei
         """
         field_list = self.model_obj.get_field_list()
         if len(field_list) == 0:
@@ -341,10 +344,10 @@ class BaseModel:
 
     def update_entity(self, model, field_list=None):
         """
-        @description: 根据模型的主键ID，更新字段的值
-        @param model: 模型实体
-        @return: 更新成功返回主键ID，否则返回空字符串
-        @last_editors: ChenXiaolei
+        :Description: 根据模型的主键ID，更新字段的值
+        :param model: 模型实体
+        :return: 更新成功返回主键ID，否则返回空字符串
+        :last_editors: ChenXiaolei
         """
         if not field_list:
             field_list = self.model_obj.get_field_list()
@@ -385,10 +388,10 @@ class BaseModel:
 
     def update_list(self, model_list, field_list=None, transaction=False):
         """
-        @description: 根据模型的主键ID，更新字段的值
-        @param model: 模型实体
-        @return: 更新成功True  更新失败Flase
-        @last_editors: ChenXiaolei
+        :Description: 根据模型的主键ID，更新字段的值
+        :param model: 模型实体
+        :return: 更新成功True  更新失败Flase
+        :last_editors: ChenXiaolei
         """
         if not model_list or len(model_list) == 0:
             return False
@@ -434,12 +437,12 @@ class BaseModel:
 
     def update_table(self, update_sql, where, params=None):
         """
-        @description: 更新数据表
-        @param update_sql: 更新set语句
-        @param where: 数据库查询条件语句
-        @param params: 参数化查询参数
-        @return: 更新成功即为True 失败则为False
-        @last_editors: ChenXiaolei
+        :Description: 更新数据表
+        :param update_sql: 更新set语句
+        :param where: 数据库查询条件语句
+        :param params: 参数化查询参数
+        :return: 更新成功即为True 失败则为False
+        :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
             where = " WHERE " + where
@@ -459,15 +462,15 @@ class BaseModel:
 
     def get_dict(self, where='', group_by='', order_by='', limit='', field="*", params=None):
         """
-        @description: 返回字典dict
-        @param where: 数据库查询条件语句
-        @param group_by: GROUP BY 语句
-        @param order_by:  ORDER BY 语句
-        @param limit:  LIMIT 语句
-        @param field: 查询字段 
-        @param params: 参数化查询参数
-        @return: 返回匹配条件的第一行字典数据
-        @last_editors: ChenXiaolei
+        :Description: 返回字典dict
+        :param where: 数据库查询条件语句
+        :param group_by: GROUP BY 语句
+        :param order_by:  ORDER BY 语句
+        :param limit:  LIMIT 语句
+        :param field: 查询字段 
+        :param params: 参数化查询参数
+        :return: 返回匹配条件的第一行字典数据
+        :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
             where = " WHERE " + where
@@ -483,11 +486,11 @@ class BaseModel:
 
     def get_dict_by_id(self, primary_key_id, field="*"):
         """
-        @description: 根据主键ID获取dict
-        @param primary_key_id: 主键id值 
-        @param field: 查询字段 
-        @return: 返回匹配id的第一行字典数据
-        @last_editors: ChenXiaolei
+        :Description: 根据主键ID获取dict
+        :param primary_key_id: 主键id值 
+        :param field: 查询字段 
+        :return: 返回匹配id的第一行字典数据
+        :last_editors: ChenXiaolei
         """
         sql = f"SELECT {field} FROM {self.table_name} WHERE {self.primary_key_field}=%s;"
         one_row = self.db.fetch_one_row(sql, primary_key_id)
@@ -495,15 +498,15 @@ class BaseModel:
 
     def get_dict_list(self, where='', group_by='', order_by='', limit='', field="*", params=None):
         """
-        @description: 返回字典列表dict list
-        @param where: 数据库查询条件语句
-        @param group_by: GROUP BY 语句
-        @param order_by:  ORDER BY 语句
-        @param limit:  LIMIT 语句
-        @param field: 查询字段 
-        @param params: 参数化查询参数
-        @return: 
-        @last_editors: ChenXiaolei
+        :Description: 返回字典列表dict list
+        :param where: 数据库查询条件语句
+        :param group_by: GROUP BY 语句
+        :param order_by:  ORDER BY 语句
+        :param limit:  LIMIT 语句
+        :param field: 查询字段 
+        :param params: 参数化查询参数
+        :return: 
+        :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
             where = " WHERE " + where
@@ -526,16 +529,16 @@ class BaseModel:
                            order_by='',
                            params=None):
         """
-        @description: 获取分页字典数据
-        @param field: 查询字段 
-        @param page_index: 分页页码 0为第一页
-        @param page_size: 分页返回数据数量
-        @param where: 数据库查询条件语句
-        @param group_by: GROUP BY 语句
-        @param order_by:  ORDER BY 语句
-        @param params: 参数化查询参数
-        @return: 数据字典数组
-        @last_editors: ChenXiaolei
+        :Description: 获取分页字典数据
+        :param field: 查询字段 
+        :param page_index: 分页页码 0为第一页
+        :param page_size: 分页返回数据数量
+        :param where: 数据库查询条件语句
+        :param group_by: GROUP BY 语句
+        :param order_by:  ORDER BY 语句
+        :param params: 参数化查询参数
+        :return: 数据字典数组
+        :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
             where = " WHERE " + where
@@ -559,10 +562,10 @@ class BaseModel:
 
     def transaction_execute(self, sql_list):
         """
-        @description: 执行事务,失败回滚
-        @param sql_list:事务SQL字符串数组
-        @return: 执行成功True 执行失败False
-        @last_editors: ChenXiaolei
+        :Description: 执行事务,失败回滚
+        :param sql_list:事务SQL字符串数组
+        :return: 执行成功True 执行失败False
+        :last_editors: ChenXiaolei
         """
         if not sql_list or len(sql_list) == 0:
             return False
@@ -570,8 +573,8 @@ class BaseModel:
 
     def is_transaction(self):
         """
-        @description: 是否开启事务
-        @last_editors: ChenXiaolei
+        :Description: 是否开启事务
+        :last_editors: ChenXiaolei
         """
         if hasattr(self, "db_transaction") and self.db_transaction and self.db_transaction.is_transaction == True:
             return True
@@ -579,11 +582,11 @@ class BaseModel:
 
     def build_add_sql(self, model_list, ignore=False):
         """
-        @description: 构造insert sql语句
-        @param model_list: 实体列表
-        @param ignore: 忽略已存在的记录
-        @return: sql语句字符串
-        @last_editors: ChenXiaolei
+        :Description: 构造insert sql语句
+        :param model_list: 实体列表
+        :param ignore: 忽略已存在的记录
+        :return: sql语句字符串
+        :last_editors: ChenXiaolei
         """
         if not model_list or len(model_list) == 0:
             return ""
@@ -608,11 +611,11 @@ class BaseModel:
 
     def build_update_sql(self, model_list, field_list=None):
         """
-        @description: 构造update sql语句
-        @param model_list: 实体列表
-        @param field_list: 需要更新的字段
-        @return: sql语句字符串
-        @last_editors: ChenXiaolei
+        :Description: 构造update sql语句
+        :param model_list: 实体列表
+        :param field_list: 需要更新的字段
+        :return: sql语句字符串
+        :last_editors: ChenXiaolei
         """
         if not model_list or len(model_list) == 0:
             return ""
@@ -640,10 +643,10 @@ class BaseModel:
 
     def build_data_sql(self, model_list):
         """
-        @description: 构造replace sql语句
-        @param model_list: 实体列表
-        @return: sql语句字符串
-        @last_editors: ChenXiaolei
+        :Description: 构造replace sql语句
+        :param model_list: 实体列表
+        :return: sql语句字符串
+        :last_editors: ChenXiaolei
         """
         if not model_list or len(model_list) == 0:
             return ""
