@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-03-21 18:29:31
-@LastEditTime: 2020-05-25 15:33:43
-@LastEditors: ChenXiaolei
-@Description: 
-@FilePath: /python_base_framework/libs/seven_framework/config.py
+:Author: ChenXiaolei
+:Date: 2020-03-21 18:29:31
+:LastEditTime: 2020-12-25 10:44:29
+:LastEditors: ChenXiaolei
+:Description: 全局配置
 """
 
 import os
@@ -17,10 +16,10 @@ _lock = threading.Condition()
 
 def init_config(path):
     """
-    @description: 初始化配置文件
-    @param path：配置文件路径，可使用物理路径或url
-    @return: global app_config
-    @last_editors: ChenXiaolei
+    :Description: 初始化配置文件
+    :param path: 配置文件路径，可使用物理路径或url
+    :return: global app_config
+    :last_editors: ChenXiaolei
     """    
     if path.lower().find("http://") > -1:
         import requests
@@ -34,11 +33,11 @@ def init_config(path):
 
 def set_value(key, value):
     """
-    @description: 设置一个全局键值配置
-    @param key:参数键名
-    @param value:参数值
-    @return: 无
-    @last_editors: ChenXiaolei
+    :Description: 设置一个全局键值配置
+    :param key:参数键名
+    :param value:参数值
+    :return: 无
+    :last_editors: ChenXiaolei
     """    
     _lock.acquire()
     try:
@@ -51,11 +50,11 @@ def set_value(key, value):
 
 def get_value(key, default_value=None):
     """
-    @description: 获得一个全局变量,不存在则返回默认值
-    @param key:参数键名
-    @param default_value:获取不到返回的默认值
-    @return: 参数值
-    @last_editors: ChenXiaolei
+    :Description: 获得一个全局变量,不存在则返回默认值
+    :param key:参数键名
+    :param default_value:获取不到返回的默认值
+    :return: 参数值
+    :last_editors: ChenXiaolei
     """
     try:
         _lock.acquire()
