@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenCheng
-@Date: 2020-05-21 11:20:06
-@LastEditTime: 2020-11-04 17:28:31
-@LastEditors: ChenXiaolei
-@Description: excel help
+:Author: ChenCheng
+:Date: 2020-05-21 11:20:06
+:LastEditTime: 2020-11-04 17:28:31
+:LastEditors: ChenXiaolei
+:Description: excel help
 """
 
 
@@ -21,8 +21,8 @@ from seven_framework import *
 
 class ExcelHelper(object):
     """
-    @description: 对excel基本操作进行封装的类
-    @last_editors: ChenCheng
+    :Description: 对excel基本操作进行封装的类
+    :last_editors: ChenCheng
     """
 
     @classmethod
@@ -40,10 +40,10 @@ class ExcelHelper(object):
     @classmethod
     def judge_format(self, filename):
         """
-        @description: 判断文件格式
-        @param filename: 文件名
-        @return: 文件格式 'xls' or 'xlsx'
-        @last_editors: ChenCheng
+        :Description: 判断文件格式
+        :param filename: 文件名
+        :return: 文件格式 'xls' or 'xlsx'
+        :last_editors: ChenCheng
         """
         file_type = re.search('xls[x]*', filename)
         if file_type:
@@ -57,10 +57,10 @@ class ExcelHelper(object):
     @classmethod
     def create_file(self, filename=''):
         """
-        @description: 创建excel文件
-        @param filename: 文件名（包含完整路径）,默认在当前文件夹下创建一个"新建Excel.xlsx"
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 创建excel文件
+        :param filename: 文件名（包含完整路径）,默认在当前文件夹下创建一个"新建Excel.xlsx"
+        :return: 
+        :last_editors: ChenCheng
         """
         if not filename:
             filename = self.__get_filename_by_xlsx()
@@ -76,10 +76,10 @@ class ExcelHelper(object):
     @classmethod
     def input(self, filename, sheet_name='Sheet'):
         """
-        @description: 从excel导入数据
-        @param filename：文件名，需要完整路径
-        @return data:二维数组形式输出数组
-        @last_editors: ChenCheng
+        :Description: 从excel导入数据
+        :param filename：文件名，需要完整路径
+        :return data:二维数组形式输出数组
+        :last_editors: ChenCheng
         """
         cell_num_begin = [1, 1]
         max_row = self.get_max_row(filename, sheet_name=sheet_name)
@@ -92,11 +92,11 @@ class ExcelHelper(object):
     @classmethod
     def export(self, data, filename=''):
         """
-        @description: 数据导出到excel
-        @param data: 字典数组 
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 数据导出到excel
+        :param data: 字典数组 
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
+        :return: 
+        :last_editors: ChenCheng
         """
         if not filename:
             filename = self.__get_filename_by_xlsx()
@@ -135,13 +135,13 @@ class ExcelHelper(object):
     @classmethod
     def updata_cell(self, row, column, value, filename='', sheet_name='Sheet'):
         """
-        @description: 单个单元格更新数据
-        @param row, column：单元格坐标（row, column）
-        @param value：要更新的数据
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
-        @param sheet_name: 表单名
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 单个单元格更新数据
+        :param row, column：单元格坐标（row, column）
+        :param value：要更新的数据
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
+        :param sheet_name: 表单名
+        :return: 
+        :last_editors: ChenCheng
         """
         data = [[value, ], ]
         cell_num_begin = [row, column]
@@ -151,13 +151,13 @@ class ExcelHelper(object):
     @classmethod
     def updata_cells(self, data, cell_num_begin, filename='', sheet_name='Sheet'):
         """
-        @description: 更新单元格数据
-        @param data: 需要更新的数据, 二维数组
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
-        @param sheet_name: 表单名
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 更新单元格数据
+        :param data: 需要更新的数据, 二维数组
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
+        :param sheet_name: 表单名
+        :return: 
+        :last_editors: ChenCheng
         """
         if not filename:
             self._create_file_by_xlsx(filename)
@@ -178,13 +178,13 @@ class ExcelHelper(object):
     @classmethod
     def read_cell(self, cell_num_begin, cell_num_end, filename='', sheet_name='Sheet'):
         """
-        @description: 读取指定位置单元格数据
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param cell_num_end: 单元格j结束位置编号,如[2,2]
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xls" 
-        @param sheet_name: 表单名
-        @return data:返回输入范围内的数据，二维数组，格式为data[[],[],...]
-        @last_editors: ChenCheng
+        :Description: 读取指定位置单元格数据
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param cell_num_end: 单元格j结束位置编号,如[2,2]
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xls" 
+        :param sheet_name: 表单名
+        :return data:返回输入范围内的数据，二维数组，格式为data[[],[],...]
+        :last_editors: ChenCheng
         """
         if not filename:
             self._create_file_by_xls(filename)
@@ -203,13 +203,13 @@ class ExcelHelper(object):
     @classmethod
     def delete_cell(self, cell_num_begin, cell_num_end, filename, sheet_name='Sheet'):
         """
-        @description: 读取指定位置单元格数据
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param cell_num_end: 单元格j结束位置编号,如[2,2]
-        @param filename: 文件名（包含地址）
-        @param sheet_name: 表单名
-        @return:
-        @last_editors: ChenCheng
+        :Description: 读取指定位置单元格数据
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param cell_num_end: 单元格j结束位置编号,如[2,2]
+        :param filename: 文件名（包含地址）
+        :param sheet_name: 表单名
+        :return:
+        :last_editors: ChenCheng
         """
         file_type = self.judge_format(filename)
         if file_type == 'xls':
@@ -226,11 +226,11 @@ class ExcelHelper(object):
     @classmethod
     def get_max_row(self, filename, sheet_name='Sheet'):
         """
-        @description: 获取最大行数
-        @param filename: 文件名
-        @param sheet_name: 表单名
-        @return: 返回选定表单有数据的最大行数
-        @last_editors: ChenCheng
+        :Description: 获取最大行数
+        :param filename: 文件名
+        :param sheet_name: 表单名
+        :return: 返回选定表单有数据的最大行数
+        :last_editors: ChenCheng
         """
         if self.judge_format(filename) == 'xls':
             if sheet_name == 'Sheet':
@@ -246,11 +246,11 @@ class ExcelHelper(object):
     @classmethod
     def get_max_column(self, filename, sheet_name='Sheet'):
         """
-        @description: 获取最大列数
-        @param filename: 文件名
-        @param sheet_name: 表单名
-        @return: 返回选定表单有数据的最大列数
-        @last_editors: ChenCheng
+        :Description: 获取最大列数
+        :param filename: 文件名
+        :param sheet_name: 表单名
+        :return: 返回选定表单有数据的最大列数
+        :last_editors: ChenCheng
         """
         if self.judge_format(filename) == 'xls':
             if sheet_name == 'Sheet':
@@ -266,11 +266,11 @@ class ExcelHelper(object):
     @classmethod
     def create_sheet(self, sheet_name, filename=''):
         """
-        @description: 创建表单，只支持xlsx
-        @param sheet_name: 表单名字
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx"
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 创建表单，只支持xlsx
+        :param sheet_name: 表单名字
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx"
+        :return: 
+        :last_editors: ChenCheng
         """
         if not filename:
             self.create_file_by_xls(filename)
@@ -287,11 +287,11 @@ class ExcelHelper(object):
     @classmethod
     def delete_sheet(self, sheet_name, filename):
         """
-        @description: 删除表单，只支持xlsx
-        @param sheet_name: 表单名字
-        @param filename: 文件名
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 删除表单，只支持xlsx
+        :param sheet_name: 表单名字
+        :param filename: 文件名
+        :return: 
+        :last_editors: ChenCheng
         """
         if self.judge_format(filename) == 'xlsx':
             excel = openpyxl.load_workbook(filename)
@@ -305,10 +305,10 @@ class ExcelHelper(object):
     @classmethod
     def _create_file_by_xls(self, filename=''):
         """
-        @description: 创建xls文件
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xls"
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 创建xls文件
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xls"
+        :return: 
+        :last_editors: ChenCheng
         """
         if not filename:
             filename = self.__get_filename_by_xls()
@@ -323,10 +323,10 @@ class ExcelHelper(object):
     @classmethod
     def _create_file_by_xlsx(self, filename=''):
         """
-        @description: 创建xlsx文件
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx"
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 创建xlsx文件
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx"
+        :return: 
+        :last_editors: ChenCheng
         """
         if not filename:
             filename = self.__get_filename_by_xlsx()
@@ -341,13 +341,13 @@ class ExcelHelper(object):
     @classmethod
     def _updata_cell_by_xls(self, data, cell_num_begin,  filename='', sheet_id=0):
         """
-        @description: 更新单元格数据
-        @param data: 需要更新的数据, 二维数组
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
-        @param sheet_id: 表单id
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 更新单元格数据
+        :param data: 需要更新的数据, 二维数组
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
+        :param sheet_id: 表单id
+        :return: 
+        :last_editors: ChenCheng
         """
         if not filename:
             self._create_file_by_xls(filename)
@@ -374,13 +374,13 @@ class ExcelHelper(object):
     @classmethod
     def _updata_cell_by_xlsx(self, data, cell_num_begin,  filename='', sheet_name='Sheet'):
         """
-        @description: 更新单元格数据
-        @param data: 需要更新的数据, 二维数组
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
-        @param sheet_name: 表单名
-        @return: 
-        @last_editors: ChenCheng
+        :Description: 更新单元格数据
+        :param data: 需要更新的数据, 二维数组
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
+        :param sheet_name: 表单名
+        :return: 
+        :last_editors: ChenCheng
         """
         if not filename:
             self._create_file_by_xls(filename)
@@ -403,13 +403,13 @@ class ExcelHelper(object):
     @classmethod
     def _read_cell_by_xls(self, cell_num_begin, cell_num_end, filename='', sheet_name='Sheet1'):
         """
-        @description: 读取指定位置单元格数据
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param cell_num_end: 单元格j结束位置编号,如[2,2]
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xls" 
-        @param sheet_name: 表单名
-        @return data:返回输入范围内的数据，格式为data[[],[],...]
-        @last_editors: ChenCheng
+        :Description: 读取指定位置单元格数据
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param cell_num_end: 单元格j结束位置编号,如[2,2]
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xls" 
+        :param sheet_name: 表单名
+        :return data:返回输入范围内的数据，格式为data[[],[],...]
+        :last_editors: ChenCheng
         """
         if not filename:
             self._create_file_by_xls(filename)
@@ -432,13 +432,13 @@ class ExcelHelper(object):
     @classmethod
     def _read_cell_by_xlsx(self, cell_num_begin, cell_num_end, filename='', sheet_name='Sheet'):
         """
-        @description: 读取指定位置单元格数据
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param cell_num_end: 单元格j结束位置编号,如[2,2]
-        @param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
-        @param sheet_name: 表单名
-        @return data:返回输入范围内的数据，二维数组，格式为data[[],[],...]
-        @last_editors: ChenCheng
+        :Description: 读取指定位置单元格数据
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param cell_num_end: 单元格j结束位置编号,如[2,2]
+        :param filename: 文件名（包含地址）,默认在当前文件夹下创建一个"新建Excel.xlsx" 
+        :param sheet_name: 表单名
+        :return data:返回输入范围内的数据，二维数组，格式为data[[],[],...]
+        :last_editors: ChenCheng
         """
         if not filename:
             self._create_file_by_xlsx(filename)
@@ -462,13 +462,13 @@ class ExcelHelper(object):
     @classmethod
     def _delete_cell_by_xls(self, cell_num_begin, cell_num_end, filename, sheet_name='Sheet1'):
         """
-        @description: 读取指定位置单元格数据
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param cell_num_end: 单元格j结束位置编号,如[2,2]
-        @param filename: 文件名（包含地址）
-        @param sheet_name: 表单名
-        @return :
-        @last_editors: ChenCheng
+        :Description: 读取指定位置单元格数据
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param cell_num_end: 单元格j结束位置编号,如[2,2]
+        :param filename: 文件名（包含地址）
+        :param sheet_name: 表单名
+        :return :
+        :last_editors: ChenCheng
         """
         if not filename:
             self._create_file_by_xlsx(filename)
@@ -488,13 +488,13 @@ class ExcelHelper(object):
     @classmethod
     def _delete_cell_by_xlsx(self, cell_num_begin, cell_num_end, filename, sheet_name='Sheet'):
         """
-        @description: 读取指定位置单元格数据
-        @param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
-        @param cell_num_end: 单元格j结束位置编号,如[2,2]
-        @param filename: 文件名（包含地址）
-        @param sheet_name: 表单名
-        @return:
-        @last_editors: ChenCheng
+        :Description: 读取指定位置单元格数据
+        :param cell_num_begin: 单元格起始位置编号,如[1,1]，注意：第一格坐标为[1,1]
+        :param cell_num_end: 单元格j结束位置编号,如[2,2]
+        :param filename: 文件名（包含地址）
+        :param sheet_name: 表单名
+        :return:
+        :last_editors: ChenCheng
         """
         if self.judge_format(filename) == 'xlsx':
             excel = openpyxl.load_workbook(filename)
