@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-04-26 14:11:31
-@LastEditTime: 2020-05-28 11:23:16
-@LastEditors: ChenXiaolei
-@Description: 
+:Author: ChenXiaolei
+:Date: 2020-04-26 14:11:31
+:LastEditTime: 2020-12-25 09:52:17
+:LastEditors: ChenXiaolei
+:Description: 服务器帮助类
 """
 import socket
 
