@@ -1,30 +1,28 @@
 '''
-@Author: ChenXiaolei
-@Date: 2020-03-14 16:12:44
-@LastEditTime: 2020-03-19 15:37:32
-@LastEditors: ChenXiaolei
-@Description: mysql helper
-@FilePath: /seven_manage_api/libs./seven_framework/mysql.py
+:Author: ChenXiaolei
+:Date: 2020-03-14 16:12:44
+:LastEditTime: 2020-03-19 15:37:32
+:LastEditors: ChenXiaolei
+:Description: mysql helper
 '''
 # -*- coding: utf-8 -*-
 import pymysql
 from DBUtils.PooledDB import PooledDB
 import traceback
+from seven_framework import config, log, json
 
 
 class MySQLHelper(object):
     # 对MySQLdb常用函数进行封装的类
-
-    error_code = ''  # MySQL错误号码
-    _instance = None  # 本类的实例
-    conn = None  # 数据库conn
+    _conn = None
     _cur = None
+    _log_sql = None
 
     def __init__(self, dbconfig):
         """
-        @description: mysql 操作类初始化
-        @param dbconfig: 连接字符串
-        @last_editors: ChenXiaolei
+        :Description: mysql 操作类初始化
+        :param dbconfig: 连接字符串
+        :last_editors: ChenXiaolei
         """
         self.POOL = PooledDB(
             creator=pymysql,  # 使用链接数据库的模块
@@ -46,70 +44,110 @@ class MySQLHelper(object):
             db=dbconfig['db'],
             charset=dbconfig['charset'])
 
+        try:
+            self._log_sql = log.Logger.get_logger_by_name("log_sql")
+        except:
+            pass
+
+    def _add_sql_log(self, log):
+        """
+        :description: 添加日志
+        :param log:日志内容
+        :return action_mode: 执行模式
+        :last_editors: ChenXiaolei
+        """
+        try:
+            if hasattr(self, "_log_sql") and self._log_sql:
+                if type(log) == int:
+                    log = str(log)
+                elif type(log) != str:
+                    log = json.JsonHelper.json_dumps(log)
+
+                self.sql_log_dict["result"] = log
+
+                self._log_sql.info(
+                    json.JsonHelper.json_dumps(self.sql_log_dict))
+        except:
+            print(traceback.print_exc())
+            pass
+
     def query(self, sql, params=None):
         """
-        @description: 执行 SELECT 语句
-        @param sql: 查询语句
-        @param params: 参数值
-        @return: 查询结果
-        @last_editors: ChenXiaolei
+        :Description: 执行 SELECT 语句
+        :param sql: 查询语句
+        :param params: 参数值
+        :return: 查询结果
+        :last_editors: ChenXiaolei
         """
         # 执行 SELECT 语句
         self._execute(sql, params)
         record_list = self._cur.fetchall()
         self.close()
+        self._add_sql_log(record_list)
         return record_list
 
     def update(self, sql, params=None):
         """
-        @description: 执行 UPDATE 操作
-        @param sql: 查询语句
-        @param params: 参数值
-        @return: 执行结果
-        @last_editors: ChenXiaolei
+        :Description: 执行 UPDATE 操作
+        :param sql: 查询语句
+        :param params: 参数值
+        :return: 执行结果
+        :last_editors: ChenXiaolei
         """
         self._execute(sql, params)
         self._conn.commit()
         row_count = self._cur.rowcount
         self.close()
+        self._add_sql_log(row_count)
         return row_count
 
     def delete(self, sql, params=None):
         """
-        @description: 执行 Delete 操作
-        @param sql: 查询语句
-        @param params: 参数值
-        @return: 执行结果
-        @last_editors: ChenXiaolei
+        :Description: 执行 Delete 操作
+        :param sql: 查询语句
+        :param params: 参数值
+        :return: 执行结果
+        :last_editors: ChenXiaolei
         """
         self._execute(sql, params)
         self._conn.commit()
         row_count = self._cur.rowcount
         self.close()
+        self._add_sql_log(row_count)
         return row_count
 
     def insert(self, sql, params=None):
         """
-        @description: 执行 INSERT 语句
-        @param sql: 数据insert语句
-        @return: 如主键为自增长int，则返回新生成的ID
-        @last_editors: ChenXiaolei
+        :Description: 执行 INSERT 语句
+        :param sql: 数据insert语句
+        :return: 如主键为自增长int，则返回新生成的ID
+        :last_editors: ChenXiaolei
         """
         # 执行 INSERT 语句。如主键为自增长int，则返回新生成的ID
         self._execute(sql, params)
         self._conn.commit()
         primary_id = self._cur._result.insert_id
         self.close()
+        self._add_sql_log(primary_id)
         return primary_id
 
     def _execute(self, sql, params=None):
+        try:
+            sql_log_dict = {}
+            sql_log_dict["sql"] = sql
+            sql_log_dict["params"] = params if type(
+                params) == str else json.JsonHelper.json_dumps(params)
+            self.sql_log_dict = sql_log_dict
+        except:
+            print(traceback.print_exc())
+            pass
+
         self.connection()
 
-        if params!=None and type(params)==int:
-            params=[params]
+        if params != None and type(params) == int:
+            params = [params]
 
         try:
-
             self._cur = self._conn.cursor(pymysql.cursors.DictCursor)
             if not params:
                 self._cur.execute(sql)
@@ -118,15 +156,15 @@ class MySQLHelper(object):
             return self._cur
         except Exception as e:
             print(traceback.print_exc())
-            raise Exception("ERROR:" + str(e) + " SQL：" + str(sql) + " 参数：" +
-                            str(params))
+            raise Exception("mysql execute error:" + str(e) + " sql:" +
+                            str(sql) + " 参数:" + str(params))
 
     def transaction_execute(self, sql_list):
         """
-        @description: 事务提交
-        @param sql_list: sql字符串数组
-        @return: 执行成功返回 True   失败 False
-        @last_editors: ChenXiaolei
+        :Description: 事务提交
+        :param sql_list: sql字符串数组
+        :return: 执行成功返回 True   失败 False
+        :last_editors: ChenXiaolei
         """
         try:
             self.connection()
@@ -152,24 +190,25 @@ class MySQLHelper(object):
 
     def fetch_all_rows(self, sql, params=None):
         """
-        @description: 返回结果列表
-        @param sql: 查询语句
-        @param params: 参数值
-        @return: 结果列表
-        @last_editors: ChenXiaolei
+        :Description: 返回结果列表
+        :param sql: 查询语句
+        :param params: 参数值
+        :return: 结果列表
+        :last_editors: ChenXiaolei
         """
         self._execute(sql, params)
         record_list = self._cur.fetchall()
         self.close()
+        self._add_sql_log(record_list)
         return record_list
 
     def fetch_limit_rows(self, sql, params=None, current_page=1, list_rows=20):
         """
-        @description: 分页查询结果
-        @param sql: 查询语句
-        @param params: 参数值
-        @return: 分页查询结果
-        @last_editors: ChenXiaolei
+        :Description: 分页查询结果
+        :param sql: 查询语句
+        :param params: 参数值
+        :return: 分页查询结果
+        :last_editors: ChenXiaolei
         """
         count = self.get_row_count(sql, params)
         pages = count / list_rows
@@ -195,61 +234,64 @@ class MySQLHelper(object):
             "pages": int(pages),
             "total": count,
         }
-
+        self._add_sql_log(result)
         return result
 
     def fetch_one_row(self, sql, params=None):
         """
-        @description: 返回一行结果，然后游标指向下一行。到达最后一行以后，返回None
-        @param sql: 查询语句
-        @param params: 参数值
-        @return: 返回一行结果
-        @last_editors: ChenXiaolei
+        :Description: 返回一行结果，然后游标指向下一行。到达最后一行以后，返回None
+        :param sql: 查询语句
+        :param params: 参数值
+        :return: 返回一行结果
+        :last_editors: ChenXiaolei
         """
         self._execute(sql, params)
         record = self._cur.fetchone()
         self.close()
+        self._add_sql_log(record)
         return record
 
     def get_row_count(self, sql, params=None):
         """
-        @description: 获取结果行数
-        @param sql: 查询语句
-        @param params: 参数值
-        @return: 返回查询行数
-        @last_editors: ChenXiaolei
+        :Description: 获取结果行数
+        :param sql: 查询语句
+        :param params: 参数值
+        :return: 返回查询行数
+        :last_editors: ChenXiaolei
         """
         self._execute(sql, params)
         row_count = self._cur.rowcount
         self.close()
+        self._add_sql_log(row_count)
         return row_count
 
     def fetch_and_commit(self, sql, params=None):
         """
-        @description: 执行并commit提交
-        @param sql: 查询语句
-        @param params: 参数值
-        @return: 返回第一行结果
-        @last_editors: ChenXiaolei
+        :Description: 执行并commit提交
+        :param sql: 查询语句
+        :param params: 参数值
+        :return: 返回第一行结果
+        :last_editors: ChenXiaolei
         """
         self._execute(sql, params)
         record = self._cur.fetchone()
         self._conn.commit()
         self.close()
+        self._add_sql_log(record)
         return record
 
     def commit(self):
         """
-        @description: 数据库commit操作
-        @last_editors: ChenXiaolei
+        :Description: 数据库commit操作
+        :last_editors: ChenXiaolei
         """
         # 数据库commit操作
         self._conn.commit()
 
     def rollback(self):
         """
-        @description: 执行数据库回滚操作
-        @last_editors: ChenXiaolei
+        :Description: 执行数据库回滚操作
+        :last_editors: ChenXiaolei
         """
         # 数据库回滚操作'
         self._conn.rollback()
@@ -259,8 +301,8 @@ class MySQLHelper(object):
 
     def __del__(self):
         """
-        @description: 执行释放资源（系统GC自动调用）
-        @last_editors: ChenXiaolei
+        :Description: 执行释放资源（系统GC自动调用）
+        :last_editors: ChenXiaolei
         """
         # 释放资源（系统GC自动调用）
         try:
@@ -271,8 +313,8 @@ class MySQLHelper(object):
 
     def close(self):
         """
-        @description: 执行关闭数据库连接
-        @last_editors: ChenXiaolei
+        :Description: 执行关闭数据库连接
+        :last_editors: ChenXiaolei
         """
         # 关闭数据库连接
         self.__del__()
@@ -280,8 +322,8 @@ class MySQLHelper(object):
 
 class DbTransaction(object):
     """
-    @description: 数据库事务执行类
-    @last_editors: ChenXiaolei
+    :Description: 数据库事务执行类
+    :last_editors: ChenXiaolei
     """
     def __init__(self, db_config_dict=None, db=None):
         self.transaction_list = []
@@ -296,9 +338,9 @@ class DbTransaction(object):
 
     def begin_transaction(self):
         """
-        @description: 启动事务
-        @return: 成功True  失败False
-        @last_editors: ChenXiaolei
+        :Description: 启动事务
+        :return: 成功True  失败False
+        :last_editors: ChenXiaolei
         """
         self.transaction_list = []
         self.is_transaction = True
@@ -306,9 +348,9 @@ class DbTransaction(object):
 
     def commit_transaction(self):
         """
-        @description: 提交事务
-        @return: 成功True  失败False
-        @last_editors: ChenXiaolei
+        :Description: 提交事务
+        :return: 成功True  失败False
+        :last_editors: ChenXiaolei
         """
         if not hasattr(self, "transaction_list"):
             return False
@@ -322,9 +364,9 @@ class DbTransaction(object):
 
     def rollback_transaction(self):
         """
-        @description: 撤销事务
-        @return: 成功True  失败False
-        @last_editors: ChenXiaolei
+        :Description: 撤销事务
+        :return: 成功True  失败False
+        :last_editors: ChenXiaolei
         """
         self.is_transaction = False
         delattr(self, "transaction_list")
@@ -333,10 +375,10 @@ class DbTransaction(object):
 
     def get_transaction_sql(self, rollback_transaction=True):
         """
-        @description: 获取事务需执行语句
-        @param is_end: 是否结束事务
-        @return: sql字符串
-        @last_editors: ChenXiaolei
+        :Description: 获取事务需执行语句
+        :param is_end: 是否结束事务
+        :return: sql字符串
+        :last_editors: ChenXiaolei
         """
         sql_list = self.transaction_list
         if not sql_list or len(sql_list) == 0:
