@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-04-16 14:38:22
-@LastEditTime: 2020-08-13 15:06:48
-@LastEditors: ChenXiaolei
-@Description: redis helper
+:Author: ChenXiaolei
+:Date: 2020-04-16 14:38:22
+:LastEditTime: 2020-08-13 15:06:48
+:LastEditors: ChenXiaolei
+:Description: redis helper
 """
 
 import redis
@@ -15,13 +15,13 @@ class RedisHelper:
     @classmethod
     def redis_init(self, host="", port=0, db=0, password=None, config_dict=None):
         """
-        @description: 从redis连接池中创建对象
-        @param host:主机地址
-        @param port:端口
-        @param db:redis_db
-        @param password:授权密码
-        @return: redis客户端对象
-        @last_editors: ChenXiaolei
+        :Description: 从redis连接池中创建对象
+        :param host:主机地址
+        :param port:端口
+        :param db:redis_db
+        :param password:授权密码
+        :return: redis客户端对象
+        :last_editors: ChenXiaolei
         """
         if config_dict:
             if "host" in config_dict:
